==> gnome-do-plugins_0.6.0.1+dfsg.orig.tar.gz: gnome-do-plugins-0.6.0.1/GNOME-Screenshot/src/ScreenshotItemSource.cs <==
/* ScreenshotItemSource.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using Mono.Unix;

using Do.Universe;

namespace GNOME {

	public class ScreenshotItemSource : IItemSource {
		
		public Type [] SupportedItemTypes {
			get {
				return new Type [] {
					typeof (ScreenshotItem),
				};
			}
		}
		
		public string Name {
			get { return Catalog.GetString ("GNOME Screenshot Items"); }
		}
		
		public string Description {
			get { return Catalog.GetString ("Whole screen or current window."); }
		}
		
		public string Icon {
			get { return "camera"; }
		}
		
		public ICollection<IItem> Items
		{
			get {
				return new IItem [] {
					new WholeScreenScreenshotItem (),
					new CurrentWindowScreenshotItem (),
				};
			}
		}
		
		public void UpdateItems ()
		{
		}
		
		public ICollection<IItem> ChildrenOfItem (IItem item)
		{
			return null;
		}
	}
}

==> gnome-do-plugins_0.8.1.3+dfsg.orig.tar.gz: gnome-do-plugins-0.8.1.3/GNOME-Screenshot/src/ScreenshotItemSource.cs <==
/* ScreenshotItemSource.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using Mono.Unix;

using Do.Universe;

namespace GNOME {

	public class ScreenshotItemSource : ItemSource {
		
		public override IEnumerable<Type> SupportedItemTypes {
			get {
				return new Type [] {
					typeof (ScreenshotItem),
				};
			}
		}
		
		public override string Name {
			get { return Catalog.GetString ("GNOME Screenshot Items"); }
		}
		
		public override string Description {
			get { return Catalog.GetString ("Whole screen or current window."); }
		}
		
		public override string Icon {
			get { return "camera"; }
		}
		
		public override IEnumerable<Item> Items
		{
			get {
				return new Item [] {
					new WholeScreenScreenshotItem (),
					new CurrentWindowScreenshotItem (),
				};
			}
		}
		
		public override void UpdateItems ()
		{
		}
		
		public override IEnumerable<Item> ChildrenOfItem (Item item)
		{
			return null;
		}
	}
}
